okerlund

package module
v0.0.0-...-e27754e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 18, 2019 License: Apache-2.0 Imports: 1 Imported by: 0

README

okerlund

Simple Go library to detect if code is running in a FaaS (AWS Lambda, GCP Function, Azure Function, Kubeless, KNative)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsAzureFunctionEnv

func IsAzureFunctionEnv() bool

IsAzureFunctionEnv checks whether code is running in an Azure Function environment

func IsGcpFunctionEnv

func IsGcpFunctionEnv() bool

IsGcpFunctionEnv checks whether code is running in a Google Cloud Platform Function environment

func IsKnativeEnv

func IsKnativeEnv() bool

IsKnativeEnv checks whether code is running in a KNative function environment

func IsKubelessEnv

func IsKubelessEnv() bool

IsKubelessEnv checks whether code is running in a Kubeless function environment

func IsLambdaEnv

func IsLambdaEnv() bool

IsLambdaEnv checks whether code is executing in an AWS Lambda environment

func IsServerlessEnv

func IsServerlessEnv() bool

IsServerlessEnv checks whether code is running in a serverless environment (any platform)

Types

This section is empty.

Jump to