Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsAzureFunctionEnv ¶
func IsAzureFunctionEnv() bool
IsAzureFunctionEnv checks whether code is running in an Azure Function environment
func IsGcpFunctionEnv ¶
func IsGcpFunctionEnv() bool
IsGcpFunctionEnv checks whether code is running in a Google Cloud Platform Function environment
func IsKnativeEnv ¶
func IsKnativeEnv() bool
IsKnativeEnv checks whether code is running in a KNative function environment
func IsKubelessEnv ¶
func IsKubelessEnv() bool
IsKubelessEnv checks whether code is running in a Kubeless function environment
func IsLambdaEnv ¶
func IsLambdaEnv() bool
IsLambdaEnv checks whether code is executing in an AWS Lambda environment
func IsServerlessEnv ¶
func IsServerlessEnv() bool
IsServerlessEnv checks whether code is running in a serverless environment (any platform)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.